@@ -55,7 +55,6 @@ def cli_node():
     """Subcommand `vnode`."""
     pass
 
-
 #
 #   list
 #
@@ -114,7 +113,6 @@ def cli_node_list():
         warning(
              f"{Fore.RED}Failed imports: {len(f1)+len(f2)}{Style.RESET_ALL}")
 
-
 #
 #   new
 #
@@ -166,7 +164,6 @@ def cli_node_new_configuration(name, environment, system_folders):
     info(f"You can start the node by running "
          f"{Fore.GREEN}vnode start {flag}{Style.RESET_ALL}")
 
-
 #
 #   files
 #
@@ -203,7 +200,8 @@ def cli_node_files(name, environment, system_folders):
     info(f"Configuration file = {ctx.config_file}")
     info(f"Log file           = {ctx.log_file}")
     info(f"data folders       = {ctx.data_dir}")
-    info("Database labels and files")
+    info(f"Database labels and files")
+
     for label, path in ctx.databases.items():
         info(f" - {label:15} = {path}")
 
@@ -215,8 +213,6 @@ help_ = {
     'config': 'absolute path to configuration-file; overrides NAME',
     'environment': 'configuration environment to use',
 }
-
-
 @cli_node.command(name='start')
 @click.option("-n", "--name", default=None, help="configuration name")
 @click.option("-c", "--config", default=None, help=help_['config'])
@@ -226,15 +222,15 @@ help_ = {
 @click.option('-i', '--image', default=None, help="Node Docker image to use")
 @click.option('--keep/--auto-remove', default=False,
               help="Keep image after finishing")
-@click.option('--force-db-mount', is_flag=True,
-              help="Skip the check of the existence of the DB (always try to "
-                   "mount)")
+@click.option('--skipp-db-exist-check/--db-exist-check', default=False,
+              help="Skipp the check of the existence of the DB (always try to \
+              mount)")
 @click.option('--attach/--detach', default=False,
               help="Attach node logs to the console after start")
 @click.option('--mount-src', default='',
               help="mount vantage6-master package source")
 def cli_node_start(name, config, environment, system_folders, image, keep,
-                   mount_src, attach, force_db_mount):
+                   mount_src, attach, skipp_db_exist_check):
     """Start the node instance.
 
         If no name or config is specified the default.yaml configuation is
@@ -261,9 +257,9 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
 
         # check that config exists, if not a questionaire will be invoked
         if not NodeContext.config_exists(name, environment, system_folders):
-            question = (f"Configuration '{name}' using environment "
-                        "'{environment}' does not exist.\n  Do you want to "
-                        "create this config now?")
+            question = f"Configuration '{name}' using environment"
+            question += f" '{environment}' does not exist.\n  Do you want to"
+            question += f" create this config now?"
 
             if q.confirm(question).ask():
                 configuration_wizard("node", name, environment, system_folders)
@@ -272,6 +268,7 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
                 error("Config file couldn't be loaded")
                 sys.exit(0)
 
+
         ctx = NodeContext(name, environment, system_folders)
 
     # check that this node is not already running
@@ -310,8 +307,10 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
         info(" ... success!")
 
     info("Creating Docker data volume")
-    data_volume = docker_client.volumes.create(
-        f"{ctx.docker_container_name}-vol")
+
+    data_volume = docker_client.volumes.create(ctx.docker_volume_name)
+    vpn_volume = docker_client.volumes.create(ctx.docker_vpn_volume_name)
+
 
     info("Creating file & folder mounts")
     # FIXME: should obtain mount points from DockerNodeContext
@@ -319,10 +318,12 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
         # (target, source)
         ("/mnt/log", str(ctx.log_dir)),
         ("/mnt/data", data_volume.name),
+        ("/mnt/vpn", vpn_volume.name),
         ("/mnt/config", str(ctx.config_dir)),
         ("/var/run/docker.sock", "/var/run/docker.sock"),
     ]
 
+
     if mount_src:
         # If mount_src is a relative path, docker will consider it a volume.
         mount_src = os.path.abspath(mount_src)
@@ -354,39 +355,30 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
     # argument ;-).
     env = {
         "DATA_VOLUME_NAME": data_volume.name,
+        "VPN_VOLUME_NAME": vpn_volume.name,
         "PRIVATE_KEY": "/mnt/private_key.pem"
     }
 
     # only mount the DB if it is a file
-    info("Setting up databases")
-    db_labels = ctx.databases.keys()
-    for label in db_labels:
-
-        uri = ctx.databases[label]
-        info(f"  Processing database '{label}:{uri}'")
-        LABEL = label.upper()
-
-        file_based = Path(uri).exists()
-        if not file_based and not force_db_mount:
-            debug('  - non file-based database added')
-            env[f'{LABEL}_DATABASE_URI'] = uri
-        else:
-            debug('  - file-based database added')
-            env[f'{LABEL}_DATABASE_URI'] = f'/mnt/{label}.csv'
-            mounts.append((f'/mnt/{label}.csv', str(uri)))
-
-        # FIXME legacy to support < 2.1.3 can be removed from 3+
-        if label == 'default':
-            env['DATABASE_URI'] = '/mnt/default.csv'
+    info("Setting up database")
+    db_is_file = Path(ctx.databases["default"]).exists()
+    env['DATABASE_URI'] = "/mnt/database.csv" if db_is_file else \
+        ctx.databases['default']
+    info(f" - URI: {env['DATABASE_URI']}")
+    if db_is_file or skipp_db_exist_check:
+        mounts.append(("/mnt/database.csv", str(ctx.databases["default"])))
+    else:
+        warning(' - Are you using a non file-based database?')
+        warning('   Or did you make a mistake in the database path?')
 
     system_folders_option = "--system" if system_folders else "--user"
     cmd = f'vnode-local start -c /mnt/config/{name}.yaml -n {name} -e '\
           f'{environment} --dockerized {system_folders_option}'
 
     info("Running Docker container")
-    volumes = []
+    volumes = {}
     for mount in mounts:
-        volumes.append(f'{mount[1]}:{mount[0]}')
+        volumes[mount[1]] = {'bind': mount[0], 'mode': 'rw'}
 
     # debug(f"  with command: '{cmd}'")
     # debug(f"  with mounts: {volumes}")
@@ -420,7 +412,6 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
                 info("Closing log file. Keyboard Interrupt.")
                 exit(0)
 
-
 #
 #   stop
 #
@@ -559,8 +550,8 @@ def cli_node_create_private_key(name, environment, system_folders, upload,
     if file_.exists() and not overwrite:
         error("Could not create private key!")
         warning(
-            "If you're **sure** you want to create a new key, "
-            "please run this command with the '--overwrite' flag"
+            f"If you're **sure** you want to create a new key, "
+            f"please run this command with the '--overwrite' flag"
         )
         warning("Continuing with existing key instead!")
         private_key = RSACryptor(file_).private_key
@@ -639,7 +630,7 @@ def cli_node_clean():
             msg += volume.name + ","
     info(msg)
 
-    confirm = q.confirm("Are you sure?")
+    confirm = q.confirm(f"Are you sure?")
     if confirm.ask():
         for volume in canditates:
             try:
@@ -679,9 +670,8 @@ def cli_node_version(name, system_folders):
 
     if name in running_node_names:
         container = client.containers.get(name)
-        version = container.exec_run(cmd='vnode-local version', stdout=True)
-        click.echo({"node": version.output.decode('utf-8'),
-                    "cli": __version__})
+        version = container.exec_run(cmd='vnode-local version', stdout = True)
+        click.echo({"node": version.output.decode('utf-8'), "cli":__version__})
 
 
 def print_log_worker(logs_stream):
